==> igniteui-webcomponents-layouts-4.3.2.tgz: package/esm2015/lib/igc-tool-action-group-header-component.js <==
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionGroupHeader } from "./ToolActionGroupHeader";
import { getAllPropertyNames, toSpinal, brushToString, stringToBrush } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
export let IgcToolActionGroupHeaderComponent = /*@__PURE__*/ (() => {
    class IgcToolActionGroupHeaderComponent extends IgcToolActionComponent {
        createImplementation() {
            return new ToolActionGroupHeader();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcToolActionGroupHeaderComponent._observedAttributesIgcToolActionGroupHeaderComponent == null) {
                let names = getAllPropertyNames(IgcToolActionGroupHeaderComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionGroupHeaderComponent._observedAttributesIgcToolActionGroupHeaderComponent = names;
            }
            return IgcToolActionGroupHeaderComponent._observedAttributesIgcToolActionGroupHeaderComponent;
        }
        static register() {
            if (!IgcToolActionGroupHeaderComponent._isElementRegistered) {
                IgcToolActionGroupHeaderComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcToolActionGroupHeaderComponent.htmlTagName, IgcToolActionGroupHeaderComponent);
            }
        }
        /**
         * Gets the actual back icon color.
        */
        get actualBackIconColor() {
            return brushToString(this.i.fb);
        }
        set actualBackIconColor(v) {
            this.i.fb = stringToBrush(v);
            this._a("actualBackIconColor", brushToString(this.i.fb));
        }
        /**
         * Gets or sets the icon color for the back button.
        */
        get backIconColor() {
            return brushToString(this.i.fc);
        }
        set backIconColor(v) {
            this.i.fc = stringToBrush(v);
            this._a("backIconColor", brushToString(this.i.fc));
        }
    }
    IgcToolActionGroupHeaderComponent._observedAttributesIgcToolActionGroupHeaderComponent = null;
    IgcToolActionGroupHeaderComponent.htmlTagName = "igc-tool-action-group-header";
    IgcToolActionGroupHeaderComponent._isElementRegistered = false;
    return IgcToolActionGroupHeaderComponent;
})();

==> igniteui-webcomponents-layouts-4.8.0.tgz: package/esm2015/lib/igc-tool-action-group-header-component.js <==
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionGroupHeader } from "./ToolActionGroupHeader";
import { getAllPropertyNames, toSpinal, brushToString, stringToBrush } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
export let IgcToolActionGroupHeaderComponent = /*@__PURE__*/ (() => {
    class IgcToolActionGroupHeaderComponent extends IgcToolActionComponent {
        createImplementation() {
            return new ToolActionGroupHeader();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcToolActionGroupHeaderComponent._observedAttributesIgcToolActionGroupHeaderComponent == null) {
                let names = getAllPropertyNames(IgcToolActionGroupHeaderComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionGroupHeaderComponent._observedAttributesIgcToolActionGroupHeaderComponent = names;
            }
            return IgcToolActionGroupHeaderComponent._observedAttributesIgcToolActionGroupHeaderComponent;
        }
        static register() {
            if (!IgcToolActionGroupHeaderComponent._isElementRegistered) {
                IgcToolActionGroupHeaderComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcToolActionGroupHeaderComponent.htmlTagName, IgcToolActionGroupHeaderComponent);
            }
        }
        /**
         * Gets the actual back icon color.
        */
        get actualBackIconColor() {
            return brushToString(this.i.ff);
        }
        set actualBackIconColor(v) {
            this.i.ff = stringToBrush(v);
            this._a("actualBackIconColor", brushToString(this.i.ff));
        }
        /**
         * Gets or sets the icon color for the back button.
        */
        get backIconColor() {
            return brushToString(this.i.fg);
        }
        set backIconColor(v) {
            this.i.fg = stringToBrush(v);
            this._a("backIconColor", brushToString(this.i.fg));
        }
    }
    IgcToolActionGroupHeaderComponent._observedAttributesIgcToolActionGroupHeaderComponent = null;
    IgcToolActionGroupHeaderComponent.htmlTagName = "igc-tool-action-group-header";
    IgcToolActionGroupHeaderComponent._isElementRegistered = false;
    return IgcToolActionGroupHeaderComponent;
})();
